TxKind

pub enum TxKind {
    Create,
    Call(Address),
}
The to field of a transaction. Either a target address, or empty for a contract creation.

Variants



Create

A transaction that creates a contract.



Call(Address)

A transaction that calls a contract or transfer.

Implementations

Source

impl TxKind

pub const fn to(&self) -> Option<&Address>

Returns the address of the contract that will be called or will receive the transfer.

pub const fn into_to(self) -> Option<Address>

Consumes the type and returns the address of the contract that will be called or will receive the transfer.

pub const fn is_create(&self) -> bool

Returns true if the transaction is a contract creation.

pub const fn is_call(&self) -> bool

Returns true if the transaction is a contract call.

pub const fn size(&self) -> usize

Calculates a heuristic for the in-memory size of this object.