Struct AlloyAccountChanges
pub struct AlloyAccountChanges {
pub address: Address,
pub storage_changes: Vec<SlotChanges>,
pub storage_reads: Vec<Uint<256, 4>>,
pub balance_changes: Vec<BalanceChange>,
pub nonce_changes: Vec<NonceChange>,
pub code_changes: Vec<CodeChange>,
}Expand description
This struct is used to track the changes across accounts in a block.
Fields
address: AddressThe address of the account whoose changes are stored.
storage_changes: Vec<SlotChanges>List of slot changes for this account.
storage_reads: Vec<Uint<256, 4>>List of storage reads for this account.
balance_changes: Vec<BalanceChange>List of balance changes for this account.
nonce_changes: Vec<NonceChange>List of nonce changes for this account.
code_changes: Vec<CodeChange>List of code changes for this account.
Implementations
impl AccountChanges
impl AccountChanges
pub const fn new(address: Address) -> AccountChanges
pub const fn new(address: Address) -> AccountChanges
Creates a new AccountChanges instance for the given address with empty vectors.
pub fn with_capacity(address: Address, capacity: usize) -> AccountChanges
pub fn with_capacity(address: Address, capacity: usize) -> AccountChanges
Creates a new AccountChanges instance for the given address with specified capacity.
pub fn storage_changes(&self) -> &[SlotChanges]
pub fn storage_changes(&self) -> &[SlotChanges]
Returns the storage changes for this account.
pub fn storage_post_states(
&self,
) -> impl Iterator<Item = (Uint<256, 4>, Uint<256, 4>)>
pub fn storage_post_states( &self, ) -> impl Iterator<Item = (Uint<256, 4>, Uint<256, 4>)>
Returns an iterator over the post-state value for each changed storage slot.
The post-state value is taken from the last recorded change for each slot.
pub fn storage_reads(&self) -> &[Uint<256, 4>]
pub fn storage_reads(&self) -> &[Uint<256, 4>]
Returns the storage reads for this account.
pub fn balance_changes(&self) -> &[BalanceChange]
pub fn balance_changes(&self) -> &[BalanceChange]
Returns the balance changes for this account.
pub fn nonce_changes(&self) -> &[NonceChange]
pub fn nonce_changes(&self) -> &[NonceChange]
Returns the nonce changes for this account.
pub fn code_changes(&self) -> &[CodeChange]
pub fn code_changes(&self) -> &[CodeChange]
Returns the code changes for this account.
pub fn sort(&mut self)
pub fn sort(&mut self)
Sorts this account’s changes in-place according to the account-local EIP-7928 ordering rules.
This applies the account-local ordering required by the “Ordering, Uniqueness and Determinism” section of EIP-7928:
storage_changesare sorted lexicographically by storage key- each per-slot
StorageChangelist is sorted by block access index in ascending order storage_readsare sorted lexicographically by storage keybalance_changes,nonce_changes, andcode_changesare sorted by block access index in ascending order
Per-slot storage change ordering is delegated to [SlotChanges::sort].
This method only canonicalizes ordering for a single account. It does not enforce the EIP-7928 uniqueness constraints for storage keys or block access indexes.
pub const fn with_address(self, address: Address) -> AccountChanges
pub const fn with_address(self, address: Address) -> AccountChanges
Set the address.
pub fn with_storage_read(self, key: Uint<256, 4>) -> AccountChanges
pub fn with_storage_read(self, key: Uint<256, 4>) -> AccountChanges
Add a storage read slot.
pub fn with_storage_change(self, change: SlotChanges) -> AccountChanges
pub fn with_storage_change(self, change: SlotChanges) -> AccountChanges
Add a storage change (multiple writes to a slot grouped in SlotChanges).
pub fn with_balance_change(self, change: BalanceChange) -> AccountChanges
pub fn with_balance_change(self, change: BalanceChange) -> AccountChanges
Add a balance change.
pub fn with_nonce_change(self, change: NonceChange) -> AccountChanges
pub fn with_nonce_change(self, change: NonceChange) -> AccountChanges
Add a nonce change.
pub fn with_code_change(self, change: CodeChange) -> AccountChanges
pub fn with_code_change(self, change: CodeChange) -> AccountChanges
Add a code change.
pub fn extend_storage_reads<I>(self, iter: I) -> AccountChangeswhere
I: IntoIterator<Item = Uint<256, 4>>,
pub fn extend_storage_reads<I>(self, iter: I) -> AccountChangeswhere
I: IntoIterator<Item = Uint<256, 4>>,
Add multiple storage reads at once.
pub fn extend_storage_changes<I>(self, iter: I) -> AccountChangeswhere
I: IntoIterator<Item = SlotChanges>,
pub fn extend_storage_changes<I>(self, iter: I) -> AccountChangeswhere
I: IntoIterator<Item = SlotChanges>,
Add multiple slot changes at once.