pub struct AlloyCodeChange {
pub block_access_index: u64,
pub new_code: Bytes,
}Expand description
This struct is used to track the new codes of accounts in a block.
Fields
block_access_index: u64The index of bal that stores this code change.
new_code: BytesThe new code of the account.
Implementations
Sourceimpl CodeChange
impl CodeChange
Sourcepub const fn new(block_access_index: u64, new_code: Bytes) -> CodeChange
pub const fn new(block_access_index: u64, new_code: Bytes) -> CodeChange
Creates a new CodeChange.
Sourcepub const fn block_access_index(&self) -> u64
pub const fn block_access_index(&self) -> u64
Returns the bal index.