pub struct AlloyStorageChange {
pub block_access_index: u64,
pub new_value: Uint<256, 4>,
}Expand description
Represents a single storage write operation within a transaction.
Fields
block_access_index: u64Index of the bal that stores the performed write.
new_value: Uint<256, 4>The new value written to the storage slot.
Implementations
Sourceimpl StorageChange
impl StorageChange
Sourcepub const fn new(
block_access_index: u64,
new_value: Uint<256, 4>,
) -> StorageChange
pub const fn new( block_access_index: u64, new_value: Uint<256, 4>, ) -> StorageChange
Creates a new StorageChange.
Sourcepub const fn is_from_tx(&self, block_index: u64) -> bool
pub const fn is_from_tx(&self, block_index: u64) -> bool
Returns true if this change was made by the given transaction.
Sourcepub const fn with_value(&self, value: Uint<256, 4>) -> StorageChange
pub const fn with_value(&self, value: Uint<256, 4>) -> StorageChange
Returns a copy with a different storage value.