pub struct JournalCfg {
pub spec: SpecId,
pub eip7708_disabled: bool,
pub eip7708_delayed_burn_disabled: bool,
}Expand description
Configuration for the journal that affects EVM execution behavior.
This struct bundles the spec ID and EIP-7708 configuration flags.
Fields
spec: SpecIdThe spec ID for the EVM. Spec is required for some journal entries and needs to be set for JournalInner to be functional.
If spec is set it assumed that precompile addresses are set as well for this particular spec.
This spec is used for two things:
eip7708_disabled: boolWhether EIP-7708 (ETH transfers emit logs) is disabled.
eip7708_delayed_burn_disabled: boolWhether EIP-7708 delayed burn logging is disabled.
When enabled, revm tracks all self-destructed addresses and emits logs for accounts that still have remaining balance at the end of the transaction. This can be disabled for performance reasons as it requires storing and iterating over all self-destructed accounts. When disabled, the logging can be done outside of revm when applying accounts to database state.